/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package benchmark.geode.data;


import org.apache.geode.benchmark.LongRange;
import org.apache.geode.cache.Region;
import org.apache.geode.cache.execute.Function;
import org.apache.geode.cache.execute.FunctionContext;
import org.apache.geode.cache.execute.RegionFunctionContext;

public class BenchmarkFunction implements Function<Void> {
  private final LongRange range;

  public BenchmarkFunction(final LongRange range) {
    this.range = range;
  }

  @Override
  public void execute(final FunctionContext<Void> context) {
    final RegionFunctionContext regionFunctionContext = (RegionFunctionContext) context;
    final Region<Long, Portfolio> region = regionFunctionContext.getDataSet();
    final Long key = range.random();
    context.getResultSender().lastResult(region.get(key));
  }

  @Override
  public String getId() {
    return BenchmarkFunction.class.getName();
  }

  @Override
  public boolean isHA() {
    return false;
  }
}
